@@ -1,3 +1,4 @@
+use anyhow::{bail, Context};
 use binwrite::BinWrite;
 use byteorder::{ReadBytesExt, LE};
 use image::{ImageBuffer, Rgba};
@@ -197,7 +198,7 @@ impl ImageBytes {
     pub fn get_image(
         &self,
         palette: &Palette,
-        resolution: &Resolution<u8>,
+        resolution: &Resolution,
         palette_id: u16,
     ) -> Result<ImageBuffer<Rgba<u8>, Vec<u8>>, ImageBytesToImageError> {
         if resolution.x == 0 || resolution.y == 0 {
@@ -242,7 +243,7 @@ pub enum DecodeImageError {
 /// Take the raw encoded image (from an [`ImageBytes`]), and decode them into a list of pixels
 pub fn decode_image_pixel(
     pixels: &[u8],
-    resolution: &Resolution<u8>,
+    resolution: &Resolution,
 ) -> Result<Vec<u8>, DecodeImageError> {
     if resolution.x % 8 != 0 {
         return Err(DecodeImageError::XResolutionNotMultipleEight(resolution.x));
@@ -260,8 +261,8 @@ pub fn decode_image_pixel(
     'main: for chunk in pixels.chunks_exact(64) {
         let mut pixel_for_chunk = chunk.iter();
         for line in 0..8 {
-            let line_start_offset =
-                (chunk_y as usize * 8 + line as usize) * resolution.x as usize + chunk_x as usize * 8;
+            let line_start_offset = (chunk_y as usize * 8 + line as usize) * resolution.x as usize
+                + chunk_x as usize * 8;
             for row_pair in 0..4 {
                 //no panic : 64 elements are guaranted, and this is looped 8*4=32 times
                 match dest.get_mut(line_start_offset + row_pair * 2 + 1) {
@@ -269,7 +270,7 @@ pub fn decode_image_pixel(
                     None => break 'main,
                 }
                 dest[line_start_offset + row_pair * 2] = *pixel_for_chunk.next().unwrap();
-            };
+            }
         }
         chunk_x += 1;
         if chunk_x > max_chunk_x {
@@ -279,3 +280,47 @@ pub fn decode_image_pixel(
     }
     Ok(dest)
 }
+
+pub fn encode_image_pixel(pixels: &[u8], resolution: &Resolution) -> anyhow::Result<Vec<u8>> {
+    if resolution.x % 8 != 0 || resolution.y % 8 != 0 {
+        bail!(
+            "The image resolution ({:?}) isn't a multiple of 8",
+            resolution
+        );
+    }
+    if resolution.x == 0 || resolution.y == 0 {
+        bail!(
+            "The image with the resolution {:?} have no pixel",
+            resolution
+        )
+    }
+    // will iterate over each line, placing them at the correct place in the output buffer
+    let mut output_buffer = vec![0; resolution.x as usize * resolution.y as usize];
+    let mut pixel_chunk_line_iter = pixels.chunks_exact(8);
+    for chunk_column in 0..(resolution.y / 8) {
+        for sub_chunk_line in 0..8 {
+            for chunk_row in 0..(resolution.x / 8) {
+                let chunk_row_data = pixel_chunk_line_iter
+                    .next()
+                    .context("The input buffer is too small")?;
+                let number_chunk_ahead: usize =
+                    chunk_column as usize * (resolution.x / 8) as usize + chunk_row as usize;
+                let pos_total = number_chunk_ahead * 64 + sub_chunk_line * 8;
+                if output_buffer.len() < pos_total + 8 {
+                    bail!("The input buffer is too small")
+                };
+                //no panic : chunk_row_data is always of length 8
+                output_buffer[pos_total] = chunk_row_data[1];
+                output_buffer[pos_total + 1] = chunk_row_data[0];
+                output_buffer[pos_total + 2] = chunk_row_data[3];
+                output_buffer[pos_total + 3] = chunk_row_data[2];
+                output_buffer[pos_total + 4] = chunk_row_data[5];
+                output_buffer[pos_total + 5] = chunk_row_data[4];
+                output_buffer[pos_total + 6] = chunk_row_data[7];
+                output_buffer[pos_total + 7] = chunk_row_data[6];
+            }
+        }
+    }
+
+    Ok(output_buffer)
+}
