@@ -24,7 +24,7 @@ pub use spritetype::SpriteType;
 
 mod imagebytes;
 pub use crate::imagebytes::{
-    decode_image_pixel, DecodeImageError, ImageBytes, ImageBytesToImageError,
+    decode_image_pixel, encode_image_pixel, DecodeImageError, ImageBytes, ImageBytesToImageError,
 };
 
 mod palette;
@@ -45,6 +45,9 @@ pub use animation::Animation;
 mod imagecompression;
 pub use imagecompression::*;
 
+mod image_to_wan;
+pub use image_to_wan::insert_frame_in_wanimage;
+
 fn get_bit_u16(byte: u16, id: u16) -> Option<bool> {
     if id < 16 {
         Some((byte >> (15 - id) << 15) >= 1)
